@@ -2,6 +2,7 @@ import copy
 
 import requests
 
+from .. import OperatorType
 from ..universe import Universe
 
 
@@ -47,29 +48,29 @@ class Pipe:
         new_pipe._object = obj
         return new_pipe
 
-    def filter(self, path: str, operator: str, value: any):
+    def filter(self, path: str, operator: OperatorType, value: any):
         new_pipe = copy.deepcopy(self)
         new_pipe._filters.append({
             'path': path,
-            'operator': operator,
+            'operator': operator.value,
             'value': value,
         })
         return new_pipe
 
     def equal(self, path: str, value: any):
-        return self.filter(path, 'eq', value)
+        return self.filter(path, OperatorType.EQUALS, value)
 
     def greater_than(self, path: str, value: any):
-        return self.filter(path, 'gt', value)
+        return self.filter(path, OperatorType.GREATER, value)
 
     def less_than(self, path: str, value: any):
-        return self.filter(path, 'lt', value)
+        return self.filter(path, OperatorType.LESS, value)
 
     def order(self, path: str, asc=True):
         new_pipe = copy.deepcopy(self)
         new_pipe._orders.append({
             'path': path,
-            'ascending': asc,
+            'descending': not asc,
         })
         return new_pipe
 
@@ -87,7 +88,7 @@ class Pipe:
                 'sort': {
                     'order': {
                         'source': self._path_source(o['path']),
-                        'ascending': o['ascending'],
+                        'descending': o['descending'],
                     },
                     'node': node,
                 }
@@ -110,6 +111,9 @@ class Pipe:
             'type': 'context',
             'context': {
                 'context': {
+                    'environment': {
+                        'type': 'primitive',
+                    },
                     'value': self._model,
                 },
                 'node': {
@@ -132,6 +136,9 @@ class Pipe:
                 'type': 'context',
                 'context': {
                     'context': {
+                        'environment': {
+                            'type': 'primitive',
+                        },
                         'value': self._object,
                     },
                     'node': self._model_node,
@@ -143,6 +150,9 @@ class Pipe:
                 'type': 'context',
                 'context': {
                     'context': {
+                        'environment': {
+                            'type': 'primitive',
+                        },
                         'value': self._model,
                     },
                     'node': {
@@ -179,7 +189,7 @@ class Pipe:
             self._node_type = endpoint_node['type']
 
             if endpoint_node['context']['value']:
-                self._model = endpoint_node['context']['context']['value']
+                self._model = endpoint_node['context']['value']
             elif endpoint_node['context']['environment'].get('model'):
                 self._model = endpoint_node['context']['environment']['model']
 
